<?php
namespace Elementor;

/**
 * If this file is called directly, abort.
 */
if(!defined('ABSPATH')){
    exit;
}

/**
 * Class  Advanced Product Features Showcase for Elementor
 */
class APFS_Widget extends Widget_Base{

    // Function for get the slug of the element name.
    public function get_name(){
        return 'advanced-product-features-showcase-for-elementor';
    }

    // Function for get the name of the element.
    public function get_title(){
        return esc_html__('Advanced Product Features', APFS_DOMAIN);
    }

    // Function for get the icon of the element.
    public function get_icon(){
        return 'eicon-column';
    }

    // Function for include element into the category.
    public function get_categories(){
        return ['advanced-product-features-showcase-for-elementor'];
    }

    // Function for include element keywords.
    public function get_keywords(){
        return ['apfs', 'advanced product features showcase'];
    }

    // Function for include css
    public function get_style_depends(){
        return ['apfs-style'];
    }

	// Adding the controls fields for the Advanced Product Features Showcase for Elementor
    protected function register_controls(){

        // Start General Section
        $this->start_controls_section(
            'apfs_section_general',array(
                'label'         => esc_html__('General', APFS_DOMAIN),
            )
        );

        $this->add_control(
            'apfs_design', [
                'label'         => esc_html__('Layouts', APFS_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options' => [
                    'design-1'  => esc_html__('Design 1', APFS_DOMAIN),
                    'design-2'  => esc_html__('Design 2', APFS_DOMAIN),
                    'design-3'  => esc_html__('Design 3', APFS_DOMAIN),
                    'design-4'  => esc_html__('Design 4', APFS_DOMAIN),
                ],
                'default'       => 'design-1',
            ]
        );

        $this->add_control(
            'apfs_heading', [
                'label'         => esc_html__('Heading', APFS_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Wireless Bluetooth Headphones', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'apfs_heading_tag', [
                'label'         => esc_html__('Heading Tag', APFS_DOMAIN),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    'h1'        => esc_html__('H1', APFS_DOMAIN),
                    'h2'        => esc_html__('H2', APFS_DOMAIN),
                    'h3'        => esc_html__('H3', APFS_DOMAIN),
                    'h4'        => esc_html__('H4', APFS_DOMAIN),
                    'h5'        => esc_html__('H5', APFS_DOMAIN),
                    'h6'        => esc_html__('H6', APFS_DOMAIN),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'apfs_image', [
                'label'         => esc_html__('Image', APFS_DOMAIN),
                'type'          => Controls_Manager::MEDIA,
                'default'       => [
                    'url'       => APFS_URL . 'assets/image/headphones.png',
                ],
            ]
        );

        $this->add_control(
			'apfs_list_icon', [
				'label'         => esc_html__('List Icon', APFS_DOMAIN),
				'type'          => Controls_Manager::ICONS,
				'default'       => [
					'value'     => 'fas fa-arrow-alt-circle-right',
					'library'   => 'fa-solid',
				],
                'condition'     => [
                    'apfs_design' => ['design-1', 'design-2'],
                ],
			]
		);

        $this->end_controls_section();
        // End Heading Section

        // Start Good Section
        $this->start_controls_section(
            'apfs_good_control', [
                'label'         => esc_html__('Good', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'good_list_title', [
                'label'         => esc_html__('Title', APFS_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('The Good', APFS_DOMAIN),
            ]
        );

        $this->add_control(
			'apfs_good_list_icon', [
				'label'         => esc_html__('Icon', APFS_DOMAIN),
				'type'          => Controls_Manager::ICONS,
				'default'       => [
					'value'     => 'far fa-thumbs-up',
					'library'   => 'fa-regular',
				],
                'condition'     => [
                    'apfs_design' => ['design-2', 'design-3'],
                ],
			]
		);

        $apfs_good = new Repeater();

        $apfs_good->add_control(
            'good_content', [
                'label'         => esc_html__('Content', APFS_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem Ipsum is simply dummy', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'good_lists', [
                'label' => esc_html__('Good List', APFS_DOMAIN),
                'type' => Controls_Manager::REPEATER,
                'fields' => $apfs_good->get_controls(),
                'default' => [
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy.', APFS_DOMAIN),
                    ],
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy typesetting industry.', APFS_DOMAIN),
                    ],
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy.', APFS_DOMAIN),
                    ],
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                    [
                        'good_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                ],
                'title_field'   => '{{{ good_content }}}',
            ]

        );

        $this->end_controls_section();
        // End Good Section

        // Start Bad Section
        $this->start_controls_section(
            'apfs_bad_control', [
                'label'         => esc_html__('Bad', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'bad_list_title', [
                'label'         => esc_html__('Title', APFS_DOMAIN),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('The Bad', APFS_DOMAIN),
            ]
        );

        $this->add_control(
			'apfs_bad_list_icon', [
				'label'         => esc_html__('Icon', APFS_DOMAIN),
				'type'          => Controls_Manager::ICONS,
				'default'       => [
					'value'     => 'far fa-thumbs-down',
					'library'   => 'fa-regular',
				],
                'condition'     => [
                    'apfs_design' => ['design-2', 'design-3'],
                ],
			]
		);

        $apfs_bad = new Repeater();

        $apfs_bad->add_control(
            'bad_content', [
                'label'         => esc_html__('Content', APFS_DOMAIN),
                'type'          => Controls_Manager::TEXTAREA,
                'default'       => esc_html__('Lorem Ipsum is simply dummy', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'bad_lists', [
                'label'         => esc_html__('Bad List', APFS_DOMAIN),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $apfs_bad->get_controls(),
                'default'       => [
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy.', APFS_DOMAIN),
                    ],
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy typesetting industry.', APFS_DOMAIN),
                    ],
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy.', APFS_DOMAIN),
                    ],
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                    [
                        'bad_content' => esc_html__('Lorem Ipsum is simply dummy the printing.', APFS_DOMAIN),
                    ],
                ],
                'title_field'   => '{{{ bad_content }}}',
            ]
        );

        $this->end_controls_section();
        // End Bad Section

        // Start Style Section

        //Start Heading style
        $this->start_controls_section(
            'apfs_heading_design',array(
                'label'         => esc_html__('Heading', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_responsive_control(
            'apfs_heading_align', [
                'label'         => esc_html__('Alignment', APFS_DOMAIN),
                'type'          =>  Controls_Manager::CHOOSE,
                'options'       => [
                    'left'      => [
						'title' => esc_html__('Left', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-left',
					],
					'center'    => [
						'title' => esc_html__('Center', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-center',
					],
					'right'     => [
						'title' => esc_html__('Right', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-right',
					],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_heading' => 'text-align:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design!' => 'design-1',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'apfs_heading_typography',
                'selector'      => '{{WRAPPER}} .apfs-advanced-product-features .apfs_heading_wrapper',
            ]
        );

        $this->add_control(
            'apfs_heading_color', [
                'label'         => esc_html__('Heading Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features  .apfs_heading_wrapper' => 'color:{{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'apfs_heading_background_color', [
                'label'         => esc_html__('Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#252324',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_heading .apfs_heading_wrapper' => 'background-color:{{VALUE}}',
                ],
                'condition'     => [
                    'apfs_design' => 'design-1'
                ],
            ]
        );

		$this->add_responsive_control(
			'apfs_heading_border_radius', [
				'label'         => esc_html__('Border Radius', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_heading .apfs_heading_wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'default'       => [
                    'top'       => 25,
                    'right'     => 25,
                    'bottom'    => 25,
                    'left'      => 25,
                ],
                'condition'     => [
                    'apfs_design' => 'design-1'
                ],
			]
		);

		$this->add_responsive_control(
			'apfs_heading_padding', [
				'label'         => esc_html__('Padding', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_heading .apfs_heading_wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'condition'     => [
                    'apfs_design' => 'design-1',
                ],
			]
		);

        $this->add_responsive_control(
            'apfs_heading_border_width', [
                'label'         => esc_html__('Border Width', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 10,
                    ]
                ],
                'default'       => ['size' => 1],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_heading_wrapper::after' => 'width:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item::before' => 'border:{{SIZE}}{{UNIT}} solid;',
                ],
                'condition'     => [
                    'apfs_design' => 'design-1',
                ],
            ]
        );

        $this->add_control(
            'apfs_heading_border_color', [
                'label'         => esc_html__('Border Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#000000',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_heading_wrapper::after' => 'background-color:{{VALUE}}',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item::before' => 'border-color:{{VALUE}}',
                ],
                'condition'     => [
                    'apfs_design' => 'design-1'
                ],
            ]
        );

        $this->add_responsive_control(
			'apfs_heading_margin', [
				'label'         => esc_html__('Heading Margin', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_heading .apfs_heading_wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_heading_wrapper::after' => 'height:{{BOTTOM}}{{UNIT}}; bottom: -{{BOTTOM}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item::before' => 'height:{{BOTTOM}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item' => 'padding-top:{{BOTTOM}}{{UNIT}};',
				],
                'default'       => [
                    'top'       => 0,
                    'right'     => 30,
                    'bottom'    => 30,
                    'left'      => 30,
                ],
                'condition'     => [
                    'apfs_design' => 'design-1',
                ],
			]
		);

        $this->add_responsive_control(
            'apfs_heading_spacing', [
                'label'         => esc_html__('Spacing', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 100,
                    ]
                ],
                'default'       => ['size' => 20],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_heading_wrapper,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_heading_wrapper,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_heading_wrapper' => 'margin-bottom:{{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-2','design-3','design-4'],
                ],
            ]
        );

        $this->end_controls_section();
        //End Heading style

         //Start Box style
        $this->start_controls_section(
            'apfs_box_design',array(
                'label'         => esc_html__('Box', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_responsive_control(
            'apfs_item_box_size', [
                'label'         => esc_html__('Box Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 350,
                    ],
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 350,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 235,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 320,
					'unit' => 'px',
				],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item .apfs_features_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details .apfs_image_media' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design'=> 'design-1', 
                ],
            ]
        );

        $this->add_responsive_control(
            'apfs_item_box_size_design_2', [
                'label'         => esc_html__('Box Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 350,
                    ]
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 300,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 350,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 320,
					'unit' => 'px',
				],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_list_item_wrapper' => 'width:{{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design'=> 'design-2',
                ],
            ]
        );

        $this->add_responsive_control(
            'apfs_item_box_size_design_3', [
                'label'         => esc_html__('Box Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 500,
                    ]
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 500,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 320,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 320,
					'unit' => 'px',
				],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_features_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list' => 'width:{{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design'=> ['design-3', 'design-4'],
                ],
            ]
        );

        $this->add_control(
            'apfs_item_box_background_color', [
                'label'         => esc_html__('Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list' => 'background-color:{{VALUE}}',
                ],
                'condition'     => [
                    'apfs_design'=> 'design-3',
                ],
            ]
        );

		$this->add_responsive_control(
			'apfs_box_border_radius_design', [
				'label'         => esc_html__('Border Radius', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_details_item .apfs_features_list, 
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_details,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_list_item_wrapper::after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'condition'     => [
                    'apfs_design'=> ['design-1','design-2','design-3'],
                ],
			]
		);

        $this->add_responsive_control(
            'apfs_box_border_width', [
                'label'         => esc_html__('Border Width', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 10,
                    ]
                ],
                'default'       => ['size' => 1],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list' => 'width:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list' => 'border:{{SIZE}}{{UNIT}} solid;',
                ],
                'condition'     => [
                    'apfs_design' => 'design-4',
                ],
            ]
        );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(), [
				'name'          => 'apfs_box_shadow',
				'selector'      => '{{WRAPPER}} .apfs-advanced-product-features .apfs_details_item .apfs_features_list',
			]
		);

        $this->add_responsive_control(
			'apfs_item_box_padding', [
				'label'         => esc_html__('Box Padding', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_features_list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design' => 'design-3',
                ],
			]
		);

        $this->add_group_control(
			Group_Control_Border::get_type(), [
                'label'         => esc_html__('Inner Box Border', APFS_DOMAIN),
				'name'          => 'apfs_content_border',
				'selector'      => '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_details',
                'condition'     => [
                    'apfs_design' => 'design-3',
                ],
			]
		);

        $this->end_controls_section();
        //End Box style

        //Start Item Title style
        $this->start_controls_section(
            'apfs_item_title_design',array(
                'label'         => esc_html__('Item Title', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'apfs_item_title_typography',
                'selector'      => '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_title',
            ]
        );

		$this->add_responsive_control(
			'apfs_item_title_padding', [
				'label'         => esc_html__('Padding', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_content_title,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_content_title .apfs_content_title_wrap,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_features_list .apfs_content_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'condition'     => [
                    'apfs_design' => ['design-1', 'design-2', 'design-3'],
                ],
			]
		);

        $this->add_responsive_control(
			'apfs_item_title_border_radius', [
				'label'         => esc_html__('Border Radius', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'.apfs-advanced-product-features .apfs-design-2 .apfs_content_title .apfs_content_title_wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'condition'     => [
                    'apfs_design' => 'design-2',
                ],
                'default'       => [
                    'top'       => 15,
                    'right'     => 15,
                    'bottom'    => 15,
                    'left'      => 15,
                ],
			]
		);

        $this->end_controls_section();
        //End Item Title style

        //Start Item Content style
        $this->start_controls_section(
            'apfs_item_content_design',array(
                'label'         => esc_html__('Item Content', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_responsive_control(
            'apfs_content_title_align', [
                'label'         => esc_html__('Alignment', APFS_DOMAIN),
                'type'          =>  Controls_Manager::CHOOSE,
                'options'       => [
                    'left'      => [
						'title' => esc_html__('Left', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-left',
					],
					'center'    => [
						'title' => esc_html__('Center', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-center',
					],
					'right'     => [
						'title' => esc_html__('Right', APFS_DOMAIN ),
						'icon'  => 'eicon-text-align-right',
					],
                ],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_content_list .apfs_list_items,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_content_list .apfs_list_items' => 'text-align:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-3', 'design-4'],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'          => 'apfs_item_content_typography',
                'selector'      => '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items',
            ]
        );

        $this->add_control(
            'apfs_item_content_text_color', [
                'label'         => esc_html__('Text Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items' => 'color:{{VALUE}}',
                ],
            ]
        );

        $this->add_control(
			'apfs_odd_bg_color', [
				'label'         => esc_html__('Odd List Background', APFS_DOMAIN ),
				'type'          => Controls_Manager::COLOR,
                'default'       => '#ffffff',
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_items:nth-child(odd)' => 'background-color: {{VALUE}}',
				],
                'condition'     => [
                    'apfs_design' =>  'design-4',
                ],
			]
		);

        $this->add_control(
			'apfs_even_bg_color', [
				'label'         => esc_html__('Even List Background', APFS_DOMAIN ),
				'type'          => Controls_Manager::COLOR,
                'default'       => '#f3f3f3',
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_items:nth-child(even)' => 'background-color: {{VALUE}}',
				],
                'condition'     => [
                    'apfs_design' =>  'design-4',
                ],
			]
		);

        $this->add_responsive_control(
            'apfs_item_content_space', [
                'label'         => esc_html__('Space Between List', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 100,
                    ]
                ],
                'default'       => ['size' => 7],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items' => 'padding-top:{{SIZE}}{{UNIT}}; padding-bottom:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
			'apfs_item_content_padding', [
				'label'         => esc_html__('Padding', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
                'default'       => [
                    'top'       => 20,
                    'right'     => 20,
                    'bottom'    => 20,
                    'left'      => 20,
                ],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_content_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_details_item .apfs_features_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_details,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_content_list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design' =>  ['design-1','design-2'],
                ],
			]
		);

		$this->add_responsive_control(
			'apfs_item_content_icon_padding', [
				'label'         => esc_html__('List Icon Spacing', APFS_DOMAIN),
				'type'          => Controls_Manager::SLIDER,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items i,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items svg' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'default'       => ['size' => 10],
                'condition'     => [
                    'apfs_design' =>  ['design-1', 'design-2'],
                ],
			]
		);

        $this->add_responsive_control(
            'apfs_item_content_icon_size', [
                'label'         => esc_html__('List Icon Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 50,
                    ]
                ],
                'default'       => ['size' => 18],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items i' => 'font-size:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_content_list .apfs_list_items svg' => 'height:{{SIZE}}{{UNIT}}; width:{{SIZE}}{{UNIT}};',
                ],
                'condition'     => [
                    'apfs_design' =>  ['design-1', 'design-2'],
                ],
            ]
        );

        $this->add_control(
			'apfs_item_content_divider_width', [
				'label'         => esc_html__('Divider Width', APFS_DOMAIN ),
				'type'          => Controls_Manager::SLIDER,
				'size_units'    =>  'px',
				'range'         => [
					'px'        => [
						'min'   => 0,
						'max'   => 10,
						'step'  => 1,
					],
				],
				'default'       => [
					'unit'      => 'px',
					'size'      => 1,
				],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_list_items::after' => 'border-bottom-width: {{SIZE}}{{UNIT}}',
                ],
                'condition'     => [
                    'apfs_design' => 'design-3',
                ],
			]
		);

        $this->add_control(
			'apfs_item_content_divider_color', [
				'label'         => esc_html__('Divider Color', APFS_DOMAIN ),
				'type'          => Controls_Manager::COLOR,
                'default'       => 'rgb(0 0 0 / 10%)',
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_list_items::after' => 'border-bottom-color: {{VALUE}}',
				],
                'condition'     => [
                    'apfs_design' => 'design-3',
                ],
			]
		);

        $this->end_controls_section();
        //End Item content style

        // Start Image style
        $this->start_controls_section(
            'apfs_image_design_section', [
                'label'         => esc_html__('Image', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
			'apfs_image_radius', [
				'label'         => esc_html__('Border Radius', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
            'apfs_item_image_size', [
                'label'         => esc_html__('Image Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 500,
                    ]
                ],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_image_media .apfs-image' => 'width:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'apfs_Image_background', [
                'label'         => esc_html__('Image Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details .apfs_image_media .apfs-image,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_image_media .apfs-image,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .apfs_image_media .apfs-image,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_image_media .apfs-image' => 'background-color:{{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
			'apfs_image_padding', [
				'label'         => esc_html__('Padding', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_image_media .apfs-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();
        //End Image style

        // Start Icon style
        $this->start_controls_section(
            'apfs_icon_design', [
                'label'         => esc_html__('Icon', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
                'condition'     => [
                    'apfs_design' => ['design-2', 'design-3'],
                ],
            ]
        );

        $this->add_responsive_control(
            'apfs_icon_background_size', [
                'label'         => esc_html__('Icon Background Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 100,
                    ]
                ],
                'default'       => ['size' => 70],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'apfs_icon_size', [
                'label'         => esc_html__('Icon Size', APFS_DOMAIN),
                'type'          => Controls_Manager::SLIDER,
                'size_units'    => ['px', '%','em'],
                'range'         => [
                    'px'        => [
                        'min'   => 0,
                        'max'   => 100,
                    ]
                ],
                'default'       => ['size' => 26],
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon i' => 'font-size:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon svg' => 'width:{{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$this->add_responsive_control(
			'apfs_icon_border_radius', [
				'label'         => esc_html__('Icon Border Radius', APFS_DOMAIN),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em'],
				'selectors'     => [
					'{{WRAPPER}} .apfs-advanced-product-features .apfs_list_item_wrapper .apfs_features_icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
                'condition'     => [
                    'apfs_design' => ['design-2', 'design-3'],
                ],
			]
		);

        $this->end_controls_section();
        //End Icon style

        // Start Color style
        $this->start_controls_section(
            'apfs_features_color', [
                'label'         => esc_html__('Color', APFS_DOMAIN),
                'tab'           => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('apfs_color_tab');

        //Start Good color style
        $this->start_controls_tab(
            'apfs_color_good', [
                'label'         => esc_html__('Good', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'apfs_title_good_color', [
                'label'         => esc_html__('Title Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       =>'#FFFFFF',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.good_list .apfs_content_title' => 'color:{{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'apfs_title_good_bg', [
                'label'         => esc_html__('Title Background', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#008C16',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.good_list .apfs_content_title,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .good_list_wrapper .apfs_content_title::before' => 'background-color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_features_list.good_list .apfs_content_title .apfs_content_title_wrap,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_features_list.good_list .apfs_content_title::after' => 'background-color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'apfs_good_list_icon_color', [
                'label'         => esc_html__('List Icon Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#008C16',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.good_list .apfs_list_items i' => 'color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.good_list .apfs_list_items svg' => 'fill:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-1','design-2'],
                ],
            ]
        );

        $this->add_control(
            'apfs_good_icon_color', [
                'label'         => esc_html__('Icon color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FFFFFF',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_good_icon i' => 'color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_good_icon svg' => 'fill:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-2','design-3'],
                ],
            ]
        );

        $this->add_control(
            'apfs_good_icon_background', [
                'label'         => esc_html__('Icon Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#008C16',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_good_icon, 
                    {{WRAPPER}} .apfs-advanced-product-features .good_list_wrapper::after' => 'background-color:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-2','design-3'],
                ],
            ]
        );

        $this->add_control(
            'apfs_good_box_background_color', [
                'label'         => esc_html__('Box Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item .apfs_features_list.good_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_details_item .apfs_features_list.good_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .good_list_wrapper .apfs_details,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list.good_list' => 'background-color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'apfs_border_good_color', [
                'label'         => esc_html__('Border Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#008C16',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list.good_list' => 'border-color:{{VALUE}}',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_item_wrapper.good_list_wrapper::before,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_item_wrapper.good_list_wrapper::after' => 'background-color:{{VALUE}}',
                ],
                'condition'     => [
                    'apfs_design' => 'design-4',
                ],
            ]
        );

        $this->end_controls_tab();
        //End Good color style

        //Start Bad color style
        $this->start_controls_tab(
            'apfs_color_bad', [
                'label'         => esc_html__('Bad', APFS_DOMAIN),
            ]
        );

        $this->add_control(
            'apfs_title_bad_color', [
                'label'         => esc_html__('Title Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       =>'#FFFFFF',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.bad_list .apfs_content_title' => 'color:{{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'apfs_title_bad_bg', [
                'label'         => esc_html__('Title Background', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#F10025',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.bad_list .apfs_content_title,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .bad_list_wrapper .apfs_content_title::before' => 'background-color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_features_list.bad_list .apfs_content_title .apfs_content_title_wrap, 
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_features_list.bad_list .apfs_content_title::after' => 'background-color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'apfs_bad_list_icon_color', [
                'label'         => esc_html__('List Icon Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#F10025',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.bad_list .apfs_list_items i' => 'color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_list.bad_list .apfs_list_items svg' => 'fill:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-1','design-2'],
                ],
            ]
        );

        $this->add_control(
            'apfs_bad_icon_color', [
                'label'         => esc_html__('Icon color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#FFFFFF',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_bad_icon i' => 'color:{{VALUE}};',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_bad_icon svg' => 'fill:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-2','design-3'],
                ],
            ]
        );

        $this->add_control(
            'apfs_bad_icon_background', [
                'label'         => esc_html__('Icon Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#F10025',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs_features_icon.apfs_bad_icon, 
                    {{WRAPPER}} .apfs-advanced-product-features .bad_list_wrapper::after' => 'background-color:{{VALUE}};',
                ],
                'condition'     => [
                    'apfs_design' => ['design-2','design-3'],
                ],
            ]
        );

        $this->add_control(
            'apfs_bad_box_background_color', [
                'label'         => esc_html__('Box Background Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-1 .apfs_details_item .apfs_features_list.bad_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-2 .apfs_details_item .apfs_features_list.bad_list,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-3 .bad_list_wrapper .apfs_details,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list.bad_list' => 'background-color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'apfs_border_bad_color', [
                'label'         => esc_html__('Border Color', APFS_DOMAIN),
                'type'          => Controls_Manager::COLOR,
                'default'       => '#F10025',
                'selectors'     => [
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_features_list.bad_list' => 'border-color:{{VALUE}}',
                    '{{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_item_wrapper.bad_list_wrapper::before,
                    {{WRAPPER}} .apfs-advanced-product-features .apfs-design-4 .apfs_list_item_wrapper.bad_list_wrapper::after' => 'background-color:{{VALUE}}',
                ],
                'condition'     => [
                    'apfs_design' => 'design-4',
                ],
            ]
        );

        $this->end_controls_tab();
        //End Bad color style

        $this->end_controls_tabs();
        //End color style

        $this->end_controls_section();
        //End Color style
    }

    /**
     * Render Advanced Product Features Showcase for Elementor widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render(){
        $settings = $this->get_settings_for_display();
        $apfs_image = ($settings['apfs_image']['url']);
        $apfs_id = attachment_url_to_postid($apfs_image);
        $image_alt = get_post_meta( $apfs_id, '_wp_attachment_image_alt', true );

        switch($settings['apfs_design']){
            case 'design-1':
                include APFS_PATH . 'include/advanced-product-features-showcase/design-1.php';
                break;
            case 'design-2':
                include APFS_PATH . 'include/advanced-product-features-showcase/design-2.php';
                break;
            case 'design-3':
                include APFS_PATH . 'include/advanced-product-features-showcase/design-3.php';
                break;
            case 'design-4':
                include APFS_PATH . 'include/advanced-product-features-showcase/design-4.php';
                break;
            default:
                include APFS_PATH . 'include/advanced-product-features-showcase/design-1.php';
                break;
        }
    }
}
plugin::instance()->widgets_manager->register(new APFS_Widget());
?>